@@ -7,9 +7,13 @@ class RidgeRegression(Regressor):
     def __init__(self, dataset: Dataset, tasks: List[Task], params: Dict[str, str]):
         super().__init__(dataset, tasks, params)
         self.model = Ridge(alpha=params["alpha"])
+        self.alpha = params["alpha"]
 
     @classmethod
     def parameters(cls):
         return {
             "alpha": [0.5, 1, 1.5]
-        }
\ No newline at end of file
+        }
+    
+    def __str__(self):
+        return f"Ridge regression - alpha={self.alpha}"
\ No newline at end of file
